from langchain.agents import Tool, initialize_agent, AgentType
from langchain.llms import OpenAI
from tools.prebuilt_tools import get_location_info_tool
from tools.ititnerary_tools import generate_itinerary_tool

def main_agent(weather_api_key, geolocation_api_key, openai_api_key):
    if not openai_api_key:
        raise ValueError("OpenAI API key is missing! Please set it in secrets or as an environment variable.")
    
    tools = [
        Tool(
            name="GetLocationInfo",
            func=lambda location: get_location_info_tool(location, geolocation_api_key, weather_api_key),
            description="Fetch location coordinates and weather information. Input: location name."
        ),
        Tool(
            name="GenerateItinerary",
            func=lambda input: generate_itinerary_tool(
                input['destination'], 
                input['days'], 
                input['context'],
                openai_api_key
            ),
            description="Generate a travel itinerary. Input: destination, days, and location context."
        )
    ]

    # Initialize the agent
    agent = initialize_agent(
        tools=tools,
        llm=OpenAI(api_key=openai_api_key, model="gpt-3.5-turbo", temperature=0.5),
        agent=AgentType.ZERO_SHOT_REACT_DESCRIPTION,
        verbose=True
    )
    return agent
